<?php
/**
 * @file
 * Contains \Drupal\notify_log\Form\NotifyLogSettingsForm.
 */

namespace Drupal\notify_log\Form;

use Drupal\Component\Utility\Unicode as Unicode;
use \Drupal\Core\Form\ConfigFormBase as ConfigFormBase;
use \Drupal\Core\Form\FormStateInterface as FormStateInterface;
use \Drupal\Core\Logger\RfcLogLevel;

class NotifyLogSettingsForm extends ConfigFormBase {

  public function getFormId() {
    return 'notify_log_settings_form';
  }

  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['notify_log_enable'] = [
      '#type' => 'checkbox',
      '#title' => t('Enable system notification (Notify OSD)'),
      '#default_value' => $this->config('notify_log.settings')->get('notify_log_enable'),
    ];
    if (!notify_log_system_capability()) {
      $form['notify_log_enable']['#attributes'] = ['disabled' => TRUE];
      $form['notify_log_enable']['#description'] = t('Notification can available only for Linux based developers, also it needed some system configuration (see README.txt file).');
    }

    $form['notify_log_severity'] = [
      '#type' => 'select',
      '#title' => t('Severity type'),
      '#description' => t('Select severity levels to display. If nothing chosen - display all types.'),
      '#options' => [
        RfcLogLevel::EMERGENCY => t('emergency'),
        RfcLogLevel::ALERT => t('alert'),
        RfcLogLevel::CRITICAL => t('critical'),
        RfcLogLevel::ERROR => t('error'),
        RfcLogLevel::WARNING => t('warning'),
        RfcLogLevel::NOTICE => t('notice'),
        RfcLogLevel::INFO => t('info'),
        RfcLogLevel::DEBUG => t('debug'),
      ],
      '#default_value' => $this->config('notify_log.settings')->get('notify_log_severity'),
      '#multiple' => TRUE,
    ];

    $form['notify_log_system_user'] = [
      '#type' => 'textfield',
      '#title' => t('System username'),
      '#description' => t('Enter username of your OS user.'),
      '#default_value' => $this->config('notify_log.settings')->get('notify_log_system_user'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if ($form_state->getValue('notify_log_enable')) {
      if (!$form_state->getValue('notify_log_system_user')) {
        $form_state->setErrorByName('notify_log_system_user', $this->t('You should specify system user name to use system notifications.'));
      }
      elseif (!notify_log_system_user_exists($form_state->getValue('notify_log_system_user'))) {
        $form_state->setErrorByName('notify_log_system_user', $this->t('There is no such user in your OS'));
      }
    }

    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('notify_log.settings')
      ->set('notify_log_enable', $form_state->getValue('notify_log_enable'))
      ->set('notify_log_system_user', $form_state->getValue('notify_log_system_user'))
      ->set('notify_log_severity', $form_state->getValue('notify_log_severity'));
    $this->config('notify_log.settings')->save();

    parent::submitForm($form, $form_state);
  }

  /**
   * Gets the configuration names that will be editable.
   *
   * @return array
   *   An array of configuration object names that are editable if called in
   *   conjunction with the trait's config() method.
   */
  public function getEditableConfigNames() {
    return ['notify_log.settings'];
  }
}
